v1.2 - Nautobot Design Builder Documentation

Skip to content

# v1.2.0 Release Notes

## Release Overview

The 1.2 release of Design Builder removes support for Nautobot 2.x from the long term support branch. Support for Nautobot 1.x will continue in the ltm-1.6 branch while Nautobot 2.0 support will remain in the develop branch.

## [v1.2.0] - 2024-05

### Removed

- Tests specific to Nautobot 2

### Changed

- No longer implementing any versioning logic to support multiple versions of Nautobot